<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el" sourcelanguage="en">
<context>
    <name>Board</name>
    <message>
        <source>Details</source>
        <translation>Λεπτομέρειες</translation>
    </message>
    <message>
        <source>Guess</source>
        <translation>Εικασία</translation>
    </message>
    <message>
        <source>Found</source>
        <translation>Βρέθηκαν</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Κανονικά</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Μεγάλα</translation>
    </message>
    <message>
        <source>Missed</source>
        <translation>Ελλειπής</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Σφάλμα</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Επιτυχία</translation>
    </message>
    <message>
        <source>Game Over</source>
        <translation>Το παιχνίδι τελείωσε</translation>
    </message>
    <message numerus="yes">
        <source>%1 of %n point(s)</source>
        <translation>
            <numerusform>%1 of %n πόντοι</numerusform>
            <numerusform>%1 από %n πόντοι</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>3 of %n point(s)</source>
        <translation>
            <numerusform>3 of %n πόντοι</numerusform>
            <numerusform>3 από %n πόντοι</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>2 of %n point(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>1 of %n point(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>0 of %n point(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n point(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>The maximum score was calculated from the following thirty words:</source>
        <translation>Το παιχνίδι που συγκέντρωσε τη μέγιστη βαθμολογία υπολογίζεται απ&apos; τις ακόλουθες τριάντα λέξεις:</translation>
    </message>
</context>
<context>
    <name>Clock</name>
    <message>
        <source>m:ss</source>
        <translation>m:ss</translation>
    </message>
    <message numerus="yes">
        <source>%n guesses(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>+%1</source>
        <translation>+%1</translation>
    </message>
    <message numerus="yes">
        <source>%n strike(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Tanglet</source>
        <translation>Tanglet</translation>
    </message>
    <message>
        <source>Classic</source>
        <translation>Κλασσικό</translation>
    </message>
    <message>
        <source>Refill</source>
        <translation>Αναπλήρωση</translation>
    </message>
    <message>
        <source>Stamina</source>
        <translation>Σθένος</translation>
    </message>
    <message>
        <source>Strikeout</source>
        <translation>Εξάλειψη</translation>
    </message>
    <message>
        <source>Allotment</source>
        <translation>Μερίδιο</translation>
    </message>
    <message>
        <source>Discipline</source>
        <translation>Πειθαρχία</translation>
    </message>
    <message>
        <source>Unlimited</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and increases on correct guesses.</source>
        <translation>Αντίστροφη μέτρηση 30&apos;&apos; κι αύξηση σε περίπτωση σωστής πρόβλεψης.</translation>
    </message>
    <message>
        <source>Counts down from 3 minutes.</source>
        <translation>Αντίστροφη μέτρηση 3&apos;.</translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and refills on correct guesses.</source>
        <translation>Αντίστροφη μέτρηση 30&apos;&apos; κι αναπλήρωση σε περίπτωση σωστής πρόβλεψης.</translation>
    </message>
    <message>
        <source>Counts down from 45 seconds and pauses on correct guesses.</source>
        <translation>Αντίστροφη μέτρηση  45&apos;&apos; και παύση  σε περίπτωση σωστής πρόβλεψης.</translation>
    </message>
    <message>
        <source>Game ends after 3 incorrect guesses.</source>
        <translation>Λήξη παιχνιδιού, μετά από 3 λάθος προβλέψεις.</translation>
    </message>
    <message>
        <source>Game ends after 30 guesses.</source>
        <translation>Λήξη παιχνιδιού, μετά από 30 προβλέψεις.</translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and increases or decreases on guesses.</source>
        <translation>Αντίστροφη μέτρηση 30&apos;&apos; κι αύξηση ή μείωση, μετά τη πρόβλεψη.</translation>
    </message>
    <message>
        <source>Game ends when all words are found.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Generator</name>
    <message>
        <source>Unable to read dice from file.</source>
        <translation>Αδυναμία ανάγνωσης ζαριού, από αρχείο.</translation>
    </message>
    <message>
        <source>Unable to read word list from file.</source>
        <translation>Αδυναμία ανάγνωσης καταλόγου λέξεων, από αρχείο.</translation>
    </message>
</context>
<context>
    <name>LanguageDialog</name>
    <message>
        <source>Board Language</source>
        <translation>Γλώσσα Ταμπλό</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Συμπεριφορά</translation>
    </message>
    <message>
        <source>Choose...</source>
        <translation>Επιλογή...</translation>
    </message>
    <message>
        <source>&lt;b&gt;Note:&lt;/b&gt; These settings will take effect when you start a new game.</source>
        <translation>&lt;b&gt;Σημείωση:&lt;/b&gt; Οι ρυθμίσεις θα εφαρμοστούν μετά την επανέναρξη του παιχνιδιού.</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>Γλώσσα:</translation>
    </message>
    <message>
        <source>Dice:</source>
        <translation>Ζάρι:</translation>
    </message>
    <message>
        <source>Word list:</source>
        <translation>Κατάλογος λέξεων:</translation>
    </message>
    <message>
        <source>Dictionary:</source>
        <translation>Λεξικό:</translation>
    </message>
    <message>
        <source>Choose Dice File</source>
        <translation>Επιλογή Αρχείου Ζαριού</translation>
    </message>
    <message>
        <source>Choose Word List File</source>
        <translation>Επιλογή Αρχείου Καταλόγου Λέξεων</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Επιλογή γλώσσας εφαρμογής:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Γλώσσα Συστήματος&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Σημείωση</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Παρακαλώ επανεκκινήστε την εφαρμογή, για να εφαρμοστούν οι αλλαγές.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Νέο Παιχνίδι</translation>
    </message>
    <message>
        <source>Amount of Words:</source>
        <translation>Αριθμός Λέξεων:</translation>
    </message>
    <message>
        <source>Minimum Word Length:</source>
        <translation>Ελάχιστο Μήκος Λέξης</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Χαμηλό</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Μέτριο</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Ψηλό</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Τυχαίο</translation>
    </message>
    <message numerus="yes">
        <source>%n letter(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>High Scores</source>
        <translation>Μεγαλύτερες Βαθμολογίες</translation>
    </message>
    <message>
        <source>Rank</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Όνομα</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Βαθμολογία</translation>
    </message>
    <message>
        <source>Maximum</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Ημερομηνία</translation>
    </message>
    <message>
        <source>Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You beat your top score!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Well done!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You have a new high score!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>N/A</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>#%1</source>
        <translation>#%1</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tanglet</source>
        <translation>Tanglet</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Paused&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Click to resume playing.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Παύση&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Κλικ για συνέχεια παιχνιδιού.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Loading game...&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Παρακαλώ περιμένετε&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Φόρτωση παιχνιδιού...&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Click to start a new game.</source>
        <translation>Κλικ για έναρξη νέου παιχνιδιού.</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Generating a new board...&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Παρακαλώ περιμένετε&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Σχεδιασμός νέου ταμπλό...&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Optimizing word list...&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Παρακαλώ περιμένετε&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Βελτιστοποίηση καταλόγου λέξεων ...&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Παιχνίδι</translation>
    </message>
    <message>
        <source>New &amp;Game...</source>
        <translation>Νέο &amp;Παιχνίδι...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>&amp;New Roll</source>
        <translation>&amp;Νέο ρίξιμο</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Επιλογή...</translation>
    </message>
    <message>
        <source>&amp;Share...</source>
        <translation>&amp;Μοίρασμα...</translation>
    </message>
    <message>
        <source>&amp;End</source>
        <translation>&amp;Τέλος</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Παύση</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>&amp;Λεπτομέρειες</translation>
    </message>
    <message>
        <source>&amp;High Scores</source>
        <translation>&amp;Μεγαλύτερες Βαθμολογίες</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Εγκατάλειψη</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Ρυθμίσεις</translation>
    </message>
    <message>
        <source>Show &amp;Maximum Score</source>
        <translation>Προβολή &amp;Μεγαλύτερων Βαθμολογιών</translation>
    </message>
    <message>
        <source>&amp;Never</source>
        <translation>&amp;Ποτέ</translation>
    </message>
    <message>
        <source>&amp;End Of Game</source>
        <translation>&amp;Τέλος Παιχνιδιού</translation>
    </message>
    <message>
        <source>&amp;Always</source>
        <translation>&amp;Πάντα</translation>
    </message>
    <message>
        <source>Show Missed &amp;Words</source>
        <translation>Προβολή Παραληφθέντων &amp;Λέξεων</translation>
    </message>
    <message>
        <source>Show Word &amp;Counts</source>
        <translation>Προβολή Μετρητή &amp;Λέξεων</translation>
    </message>
    <message>
        <source>&amp;Board Language...</source>
        <translation>&amp;Γλώσσα Ταμπλό...</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Γλώσσα &amp;Εφαρμογής</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Βοήθεια</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Έλεγχοι</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Σχετικά</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Σχετικά &amp;με το Qt</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
        <translation>Συγγραφέας &amp;δικαιώματα; 2009-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Tanglet %1</source>
        <translation>Tanglet %1</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Σχετικά</translation>
    </message>
    <message>
        <source>A single player variant of &lt;a href=&quot;http://en.wikipedia.org/wiki/Boggle&quot;&gt;Boggle&lt;/a&gt;</source>
        <translation>Μια παραλλαγή για ένα παίχτη, του &lt;a href=&quot;http://en.wikipedia.org/wiki/Boggle&quot;&gt;Boggle&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Έκδοση υπό &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; άδεια</translation>
    </message>
    <message>
        <source>English word list is based on &lt;a href=&quot;http://wordlist.sourceforge.net/&quot;&gt;SCOWL&lt;/a&gt; by Kevin Atkinson</source>
        <translation>Ο Αγγλικός κατάλογος λέξεων, βασίστηκε στο &lt;a href=&quot;http://wordlist.sourceforge.net/&quot;&gt;SCOWL&lt;/a&gt; του Kevin Atkinson</translation>
    </message>
    <message>
        <source>Hebrew word list is based on &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; by Nadav Har&apos;El and Dan Kenigsberg</source>
        <translation>Ο Εβραϊκός κατάλογος λέξεων, βασίστηκε στο &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; των Nadav Har&apos;El και Dan Kenigsberg</translation>
    </message>
    <message>
        <source>Import Game</source>
        <translation>Εισαγωγή παιχνιδιού</translation>
    </message>
    <message>
        <source>Tanglet Games (*.tanglet)</source>
        <translation>Παιχνίδια Tanglet (*.tanglet)</translation>
    </message>
    <message>
        <source>Unable to start requested game.</source>
        <translation>Αδυναμία έναρξης του ζητουμένου παιχνιδιού.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Σφάλμα</translation>
    </message>
    <message>
        <source>Export Game</source>
        <translation>Εξαγωγή παιχνιδιού</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Ερώτηση</translation>
    </message>
    <message>
        <source>End the current game?</source>
        <translation>Λήξη παιχνιδιού;</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Λεπτομέρειες</translation>
    </message>
    <message>
        <source>Board Size:</source>
        <translation>Μέγεθος Ταμπλό:</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Κανονικό</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Μεγάλο</translation>
    </message>
    <message>
        <source>Word Density:</source>
        <translation>Πυκνότητα Λέξης:</translation>
    </message>
    <message>
        <source>Word Length:</source>
        <translation>Μήκος Λέξης:</translation>
    </message>
    <message>
        <source>%1 or more letters</source>
        <translation>%1 ή περισσότερα γράμματα</translation>
    </message>
    <message>
        <source>Game Type:</source>
        <translation>Τύπος Παιχνιδιού:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Περιγραφή:</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Έλεγχοι:</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Mouse Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Click on the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Click on the last selected letter.&lt;br&gt;&lt;b&gt;Erase letters:&lt;/b&gt; Click on an earlier selected letter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Click twice on the first selected letter.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Keyboard Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Type the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Press Enter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Press Ctrl+Backspace.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Παιχνίδι Ποντικιού:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Επιλέξτε λέξη:&lt;/b&gt; Κλικ στα γράμματα της λέξης.&lt;br&gt;&lt;b&gt;Κάντε μια πρόβλεψη:&lt;/b&gt; Κλικ στο τελευταίο επιλεγμένο γράμμα.&lt;br&gt;&lt;b&gt;Διαγράψτε γράμματα:&lt;/b&gt;Κλικ σε προηγουμένως επιλεγμέν γράμμα.&lt;br&gt;&lt;b&gt;Καθαρισμός λέξης:&lt;/b&gt;Διπλό κλικ στο πρώτο επιλεγμένο γράμμα.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Παιχνίδι Πληκτρολογίου:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Επιλέξτε λέξη:&lt;/b&gt; Πληκτρολογήστε τα γράμματα της λέξης.&lt;br&gt;&lt;b&gt;Κάντε μια πρόβλεψη:&lt;/b&gt; Πατήστε Enter.&lt;br&gt;&lt;b&gt;Καθαρισμός λέξης:&lt;/b&gt; Πατήστε Ctrl+Backspace.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WordCounts</name>
    <message>
        <source>Letters:</source>
        <translation>Γράμματα:</translation>
    </message>
    <message>
        <source>Found:</source>
        <translation>Βρέθηκαν:</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;&lt;b&gt;%2&lt;/b&gt;</source>
        <translation>%1&lt;br&gt;&lt;b&gt;%2&lt;/b&gt;</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;&lt;b&gt;%2/%3&lt;/b&gt;</source>
        <translation>%1&lt;br&gt;&lt;b&gt;%2/%3&lt;/b&gt;</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;%2/%3</source>
        <translation>%1&lt;br&gt;%2/%3</translation>
    </message>
</context>
<context>
    <name>WordTree</name>
    <message numerus="yes">
        <source>%n point(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Word finding game</source>
        <translation>Παιχνίδι εύρεσης λέξεων</translation>
    </message>
    <message>
        <source>A game file to play.</source>
        <translation>Αρχείο παιχνιδιού.</translation>
    </message>
</context>
</TS>
